@@ -98,7 +98,7 @@ const char * KviIrcMask::setMask(const char *szMask,char c)
 	__range_valid(szMask);
 	//nick!username@host.top
 	//0123456789
-	register const char *p=szMask;
+	const char *p=szMask;
 	//Run over nick....
 	while(*p && (*p != '!'))p++;
 	int len = p - szMask;
@@ -154,7 +154,7 @@ const char * KviIrcMask::setUserhostMask(const char *szMask)
 	__range_valid(szMask);
 	//nick[*]=<+!->username@host.top
 	//0123456789
-	register const char *p=szMask;
+	const char *p=szMask;
 	// Run over nick....
 	while(*p && (*p != '*') && (*p != '=') && (!isspace(*p)))p++;
 	// extract it
