@@ -25,7 +25,7 @@
 
 #include "kvi_settings.h"
 
-#ifdef COMPILE_KDE_SUPPORT
+#ifdef COMPILE_TDE_SUPPORT
 	#include "kvi_tal_mainwindow_kde.h"
 #else
 	#ifdef COMPILE_USE_QT4
