@@ -505,11 +505,11 @@ KviIconManager::KviIconManager()
 		nnn += ".png";
 		if(tmp->isNull())
 		{
-			debug("OPS, %s is NULL",nnn.latin1());
+			tqDebug("OPS, %s is NULL",nnn.latin1());
 		}
 		if(!tmp->save(nnn,"PNG",90))
 		{
-			debug("FAILED TO SAVE %s",nnn.latin1());
+			tqDebug("FAILED TO SAVE %s",nnn.latin1());
 		}
 	}
 	*/
