@@ -921,7 +921,7 @@ void KviServerParser::parseLiteralPrivmsg(KviIrcMessage *msg)
 						#else
 							TQString szMsg = TQStyleSheet::escape(szMsgText);
 						#endif
-						//debug("kvi_sp_literal.cpp:908 debug: %s",szMsg.data());
+						//tqDebug("kvi_sp_literal.cpp:908 debug: %s",szMsg.data());
 						g_pApp->notifierMessage(query,KVI_SMALLICON_QUERYPRIVMSG,szMsg,1800);
 					}
 				}
@@ -1279,7 +1279,7 @@ void KviServerParser::parseLiteralNotice(KviIrcMessage *msg)
 						#else
 							TQString szMsg = TQStyleSheet::escape(szMsgText);
 						#endif
-						//debug("kvi_sp_literal.cpp:908 debug: %s",szMsg.data());
+						//tqDebug("kvi_sp_literal.cpp:908 debug: %s",szMsg.data());
 						g_pApp->notifierMessage(query,KVI_SMALLICON_QUERYNOTICE,szMsg,1800);
 					}
 				}
@@ -1507,7 +1507,7 @@ void KviServerParser::parseLiteralNick(KviIrcMessage *msg)
 		{
 			// the target SHOULD have changed his nick here
 			if(!q->nickChange(szNick,szNewNick))
-					debug("Internal error: query %s failed to change nick from %s to s",szNick.utf8().data(),szNick.utf8().data(),szNewNick.utf8().data());
+					tqDebug("Internal error: query %s failed to change nick from %s to s",szNick.utf8().data(),szNick.utf8().data(),szNewNick.utf8().data());
 			if(!msg->haltOutput())
 				q->output(KVI_OUT_NICK,__tr2qs("\r!n\r%Q\r [%Q@\r!h\r%Q\r] is now known as \r!n\r%Q\r"),
 					&szNick,&szUser,&szHost,&szNewNick);
