@@ -473,12 +473,12 @@ void KviCustomToolBar::drag(TQWidget * child,const TQPoint &pnt)
 {
 	int me = -1;
 	int idx = dropIndexAt(pnt,child,&me);
-	debug("DROP INDEX IS %d, ME IS %d",idx,me);
+	tqDebug("DROP INDEX IS %d, ME IS %d",idx,me);
 	if(idx == me)
 		return; // would move over itself
 #ifdef COMPILE_USE_QT4
 	TQWidget * pWidgetToMove = widgetAt(idx > me ? idx-1 : idx);
-	debug("SEARCHING FOR WIDGET TO MOVE AT %d AND FOUND %x (ME=%x)",idx > me ? idx-1 : idx,pWidgetToMove,child);
+	tqDebug("SEARCHING FOR WIDGET TO MOVE AT %d AND FOUND %x (ME=%x)",idx > me ? idx-1 : idx,pWidgetToMove,child);
 	if(pWidgetToMove == child)
 		return; // hmmm
 	bool bDone = false;
@@ -492,7 +492,7 @@ void KviCustomToolBar::drag(TQWidget * child,const TQPoint &pnt)
 		a = actionForWidget(pWidgetToMove);
 		if(a)
 		{
-			debug("AND GOT ACTION FOR THAT WIDGET");
+			tqDebug("AND GOT ACTION FOR THAT WIDGET");
 
 			bDone = true;
 			a = insertWidget(a,child);
