@@ -1034,7 +1034,7 @@ void KviWindow::focusInEvent(TQFocusEvent *)
 		if(m_pFocusHandler)m_pFocusHandler->setFocus();
 		else {
 			// else too bad :/
-			debug("No widget able to handle focus for window %s",name());
+			tqDebug("No widget able to handle focus for window %s",name());
 			return;
 		}
 	} else {
@@ -1047,7 +1047,7 @@ void KviWindow::focusInEvent(TQFocusEvent *)
 	// we should be already the active window at this point.
 	// If we're not, then run activateSelf() to fix this.
 	if(g_pActiveWindow != this)activateSelf();
-	//else debug("ACTIVE WINDOW IS ALREADY THIS");
+	//else tqDebug("ACTIVE WINDOW IS ALREADY THIS");
 	updateCaption();
 }
 
@@ -1154,7 +1154,7 @@ void KviWindow::childDestroyed()
 
 void KviWindow::childRemoved(TQWidget * o)
 {
-	//debug("CHILD REMOVED %d",o);
+	//tqDebug("CHILD REMOVED %d",o);
 	o->removeEventFilter(this);
 	if(o == m_pFocusHandler)
 		m_pFocusHandler = 0;
@@ -1180,7 +1180,7 @@ void KviWindow::childRemoved(TQWidget * o)
 			if(c->isWidgetType())
 				childRemoved((TQWidget *)c);
 		}
-	} //else debug("The removed object has no children");
+	} //else tqDebug("The removed object has no children");
 #endif
 }
 
